==> nanoblogger-2.2.tar.gz: nanoblogger/plugins/calendar.sh <==
#! /bin/bash
# 
# NanoBlogger Calendar Plugin, requires the cal program.
# converts the output of cal to HTML and creates links entries
#
# sample code for template - based off default stylesheet
#
# <div class="side">
# $NB_Calendar
# </div>

OUTPUT_FILE="$BLOG_DIR/$PARTS_DIR/cal.htm"

if cal > /dev/null 2>&1 ; then

	CALENDAR=`cal`
	CAL_HEAD=`echo "$CALENDAR" |sed -n 1p |sed -e 's/^[ ]*//g'`
	WEEK_DAYS=`echo "$CALENDAR" |sed -n 2p`
	DAYS=`echo "$CALENDAR" |sed 1,2d`
	NUM_DAY_LINES=`echo "$DAYS" |grep -n "" |cut -c1`

	curr_month=`date +%m`
	MONTH_LIST=`cd "$BLOG_DIR"/"$ARCHIVES" ; for files in *.* ; do echo "$files" ; done |sort -r |grep '[-]'$curr_month'[-]'`

	html_nbsp="&nbsp;"

	echo '<table border="0" cellspacing="4" cellpadding="0">' > "$OUTPUT_FILE"
	echo '<caption>'$CAL_HEAD'</caption>' >> "$OUTPUT_FILE"
	echo '<tr>' >> "$OUTPUT_FILE"
	for wd in $WEEK_DAYS ; do
		echo '<th align="center"><span>'$wd'</span></th>' >> "$OUTPUT_FILE"
	done
	echo '</tr>' >> "$OUTPUT_FILE"
	for line in $NUM_DAY_LINES ; do
		DN_LINES=`echo "$DAYS" |sed -n "$line"p`
		echo '<tr>' >> "$OUTPUT_FILE"
		echo "$DN_LINES" | sed 's/  [ \t]/<td align="center"><span>\'$html_nbsp'\<\/span><\/td>\ /g ; s/[0-9]//g' >> "$OUTPUT_FILE"
		for dn in $DN_LINES ; do
			set_link="0"
			MONTH_LINE=`echo "$MONTH_LIST" |grep $dn`
			for entry in $MONTH_LINE ; do
				entry_year=`echo $entry |cut -c1-4`
				entry_month=`echo $entry |cut -c6-7`
				entry_day=`echo $entry |cut -c9-10 |sed -e 's/^0//g'`
				curr_month=`date +%m`
				curr_year=`date +%Y`
			if [ "$curr_year-$curr_month-$dn" = "$entry_year-$entry_month-$entry_day" ] ; then
				set_link="1"
				dn='<a href="'$BLOG_URL'/'$ARCHIVES'/'$FILE_BY_DIR'/'$entry_year-$entry_month'.html#'$entry'">'$dn'</a>'
				echo '<td align="center"><span>'$dn'</span></td>' >> "$OUTPUT_FILE"
			fi
			done
			if [ "$set_link" != "1" ] ; then
				echo '<td align="center"><span>'$dn'</span></td>' >> "$OUTPUT_FILE"
			fi
		done
		echo '</tr>' >> "$OUTPUT_FILE"
	done
	echo '</table>' >> "$OUTPUT_FILE"

	# The calendar's place-holder for the templates
	NB_Calendar=`cat "$OUTPUT_FILE"`
fi

==> nanoblogger-2.4.tar.gz: nanoblogger/plugins/calendar.sh <==
# NanoBlogger Calendar Plugin, requires the cal command.
# converts the output of cal to an HTML Table and creates links of entries
#
# sample code for template - based off default stylesheet
#
# <div class="side">
# $NB_Calendar
# </div>

OUTPUT_FILE="$BLOG_DIR/$PARTS_DIR/cal.htm"

if cal > /dev/null 2>&1 ; then

	CALENDAR=`cal`
	CAL_HEAD=`echo "$CALENDAR" |sed -n 1p |sed -e 's/^[ ]*//g'`
	WEEK_DAYS=`echo "$CALENDAR" |sed -n 2p`
	DAYS=`echo "$CALENDAR" |sed 1,2d`
	NUM_DAY_LINES=`echo "$DAYS" |grep -n "" |cut -c1`

	curr_month=`date +%m`
	MONTH_LIST=`cd "$BLOG_DIR"/"$ARCHIVES" ; for files in *.* ; do echo "$files" ; done |sort -r |grep '[-]'$curr_month'[-]'`

	html_nbsp="&nbsp;"

	echo '<table border="0" cellspacing="4" cellpadding="0">' > "$OUTPUT_FILE"
	echo '<caption>'$CAL_HEAD'</caption>' >> "$OUTPUT_FILE"
	echo '<tr>' >> "$OUTPUT_FILE"
	for wd in $WEEK_DAYS ; do
		echo '<th align="center"><span class="calendar">'$wd'</span></th>' >> "$OUTPUT_FILE"
	done
	echo '</tr>' >> "$OUTPUT_FILE"
	for line in $NUM_DAY_LINES ; do
		DN_LINES=`echo "$DAYS" |sed -n "$line"p`
		echo '<tr>' >> "$OUTPUT_FILE"
		echo "$DN_LINES" | sed 's/  [ \t]/<td align="center"><span class="calendar">\'$html_nbsp'\<\/span><\/td>\ /g ; s/[0-9]//g' >> "$OUTPUT_FILE"
		for dn in $DN_LINES ; do
			set_link="0"
			MONTH_LINE=`echo "$MONTH_LIST" |grep $dn`
			for entry in $MONTH_LINE ; do
				entry_year=`echo $entry |cut -c1-4`
				entry_month=`echo $entry |cut -c6-7`
				entry_day=`echo $entry |cut -c9-10 |sed -e 's/^0//g'`
				curr_month=`date +%m`
				curr_year=`date +%Y`
			if [ "$curr_year-$curr_month-$dn" = "$entry_year-$entry_month-$entry_day" ] ; then
				set_link="1"
				if [ "$FULL_PERMALINKS" = "1" ] ; then
					dn='<a href="'$BLOG_URL_ACTION''$PERMALINKS'/'$entry'">'$dn'</a>'
				else
					dn='<a href="'$BLOG_URL'/'$ARCHIVES'/'$FILE_BY_DIR'/'$entry_year-$entry_month'.html#'$entry'">'$dn'</a>'
				fi
				echo '<td align="center"><span>'$dn'</span></td>' >> "$OUTPUT_FILE"
			fi
			done
			if [ "$set_link" != "1" ] ; then
				echo '<td align="center"><span>'$dn'</span></td>' >> "$OUTPUT_FILE"
			fi
		done
		echo '</tr>' >> "$OUTPUT_FILE"
	done
	echo '</table>' >> "$OUTPUT_FILE"

	# The calendar's place-holder for the templates
	NB_Calendar=`cat "$OUTPUT_FILE"`
fi
